<?php

/**

 * @package Notipack

 */

/*

Plugin Name: Notipack Integration

Plugin URI: http://app.notipack.com

Description: This plugin will automatically add notifications from notipack to your site and send the information needed to create them.

Version: 1.1.3

Author: Notipack

Author URI: http://app.notipack.com

License: GPLv2 or later

Text Domain: notipack-integration

*/



/*

This program is free software; you can redistribute it and/or

modify it under the terms of the GNU General Public License

as published by the Free Software Foundation; either version 2

of the License, or (at your option) any later version.



This program is distributed in the hope that it will be useful,

but WITHOUT ANY WARRANTY; without even the implied warranty of

MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the

GNU General Public License for more details.



You should have received a copy of the GNU General Public License

along with this program; if not, write to the Free Software

Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

 */



defined('ABSPATH') or die('Hey, you can not access this file');


error_reporting(0);


class NotipackIntegration

{



    function __construct()

    {

        add_action('wp_head', array($this, 'include_pixel_code'));

        add_action('admin_menu', array($this, 'setup_menu'));

        add_action( 'woocommerce_checkout_order_created', array( $this, 'get_product_data' ), 90, 3 );

        if(isset($_POST['refresh'])){
            add_action('init', array($this, 'notipack_call_api'));
        }elseif (isset($_POST['unique_code'])) {
            add_action('init', array($this, 'notipack_call_api'));
        }

    }



  
function get_product_data($order_id)
    {
		

        if (!$order_id) {
            return;
		}



        $order = wc_get_order($order_id);

 if ( $order ) {

        foreach ($order->get_items() as $item_id => $item) {



            if ($item['variation_id'] > 0) {
                $product_id = $item['variation_id'];
			} else {
                $product_id = $item['product_id'];
		    }



            $product = wc_get_product($product_id);

            $thumbnail = get_the_post_thumbnail_url($product_id);

            if(!filter_var($thumbnail, FILTER_VALIDATE_URL)){
                $thumbnail = wp_get_attachment_url($product->get_image_id());
            }

        }

        $product_data = [

          'thumbnail' => $thumbnail ?? NULL,

            'buyer_name' => $order->get_billing_first_name() ?? NULL,

            'product_name' => $product->get_name() ?? NULL,

            'product_link' => $product->get_permalink() ?? NULL,

            'city' =>  $order->get_data()['billing']['city'] ?? NULL

        ];



        $this->send_order_data_to_notipack($product_data);

 }
    }



    function setup_menu()

    {

        add_menu_page('Notipack Integration', 'Notipack Integration', 'manage_options', 'notipack_integration', array($this, 'load_form'));

    }



    function load_form()

    {

        global $wpdb;
        $code = $wpdb->get_results("SELECT * FROM `".$wpdb->base_prefix."options` WHERE `option_name` LIKE 'unique_code'");
        if(count($code) == 1) {
            $code = $code[0]->option_value;
        } else {
            $code = '';
        }
        echo '
       
		 
				
                    <link rel="stylesheet" href="/wp-content/plugins/notipack-integration/assets/admin_panel_style.css">
            <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.0.1/dist/css/bootstrap.min.css" rel="stylesheet">
    				<style>
                   
					</style>
            <div class="items rounded col-6 p-2">
                <div class="title d-flex">
                    <h1 class="title">
                        <span class="underline">Integracja</span>
                        <span>Z Notipack.com </span>
                    </h1>
                </div>
        
                <p class="text-muted pt-2 mb-3">Tutaj możesz dokonać pełnej integracji z serwisem <b>Notipack.com!</b> <br>
                    Wystarczy, że po utworzeniu kampanii oraz notyfikacji skopiujesz <b>klucz do integracji</b> oraz wkleisz go
                    poniżej!</p>
                <hr>
                <p class="text-danger pt-2 mt-1"> Jeżeli występują jakiekolwiek problemy upewnij się, że masz najnowszą wersję wtyczki pobraną z <a href="https://pomoc.notipack.com/">Pomoc</a></p>

                <p class="text-danger pt-2 mt-5">Pamiętaj, aby po każdej zmianie w serwisie Notipack.com <br> ponownie odświeżyć dane klikając przycisk "Odśwież" poniżej
                </p>
        
        
                <form method="POST" class="row">
                    <div class=" col-7 pt-3">
                        <input id="input" name="unique_code" type="text" placeholder="Wklej swój klucz"
                               class="form-control rounded" value="'.$code.'" oninput="changeButton()"/>
                    </div>
                    <div class="col-7 pt-2  align-items-center">
                        <button type="submit" class="xbutton">Wyślij</button>
        
                    </div>
        
        
                </form>
                <form method="POST">
                    <input type="hidden" name="refresh">
                    <div class="col-7 pt-2  align-items-center">
                        <button type="submit" class="xbutton">Odśwież</button>
        
                    </div>
                </form>
        
            </div>
        
        <script>
            let inputValue = document.getElementById("input");
            let button = document.getElementById("buttonSend");
        
            function changeButton() {
                if (inputValue.value.length == 13) {
        
                    button.disabled = false;
                } else {
                    warning.innerHTML = "Niepoprawny kod!";
                    button.disabled = true;
        
                }
            }
        
        </script>';

    }



    function include_pixel_code()

    {

        $pixel_code = get_option('pixel_code') ?? NULL;



        if (isset($pixel_code)) {

            ?>

            <!-- Pixel Code for https://app.notipack.com/ -->

            <script async src="https://app.notipack.com/pixel/<?= $pixel_code; ?>"></script>

            <!-- END Pixel Code -->

            <?php

        }

    }





    function register()

    {



    }





    function activate()

    {

        return true;

    }



    function deactivate()

    {

        return true;

    }



    function send_order_data_to_notipack($product_data)

    {

        $urls = get_option('LATEST_CONVERSION') ?? NULL;

		foreach( $urls as $url ) {

            $curl = curl_init();



            curl_setopt_array($curl, array(

                CURLOPT_URL => $url,

                CURLOPT_RETURNTRANSFER => true,

                CURLOPT_ENCODING => '',

                CURLOPT_MAXREDIRS => 10,

                CURLOPT_TIMEOUT => 0,

                CURLOPT_FOLLOWLOCATION => false,

                CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,

                CURLOPT_CUSTOMREQUEST => 'POST',

                CURLOPT_POSTFIELDS => $product_data,

            ));



            $response = curl_exec($curl);



            curl_close($curl);



       
		}
		
		 $urls = get_option('CONVERSIONS_COUNTER') ?? NULL;

		foreach( $urls as $url ) {

            $curl = curl_init();



            curl_setopt_array($curl, array(

                CURLOPT_URL => $url,

                CURLOPT_RETURNTRANSFER => true,

                CURLOPT_ENCODING => '',

                CURLOPT_MAXREDIRS => 10,

                CURLOPT_TIMEOUT => 0,

                CURLOPT_FOLLOWLOCATION => false,

                CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,

                CURLOPT_CUSTOMREQUEST => 'POST',

                CURLOPT_POSTFIELDS => $product_data,

            ));



            $response = curl_exec($curl);



            curl_close($curl);



       
		}


        return true;

    }



    function notipack_call_api()

    {
		
		 


        $curl = curl_init();



        if(isset($_POST['refresh'])){

            $unique_code = get_option('unique_code');

        }else {

            $unique_code = $_POST['unique_code'];

        }



        curl_setopt_array($curl, array(

            CURLOPT_URL => 'http://app.notipack.com/api/',

            CURLOPT_RETURNTRANSFER => true,

            CURLOPT_ENCODING => '',

            CURLOPT_MAXREDIRS => 10,

            CURLOPT_TIMEOUT => 0,

            CURLOPT_FOLLOWLOCATION => false,

            CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,

            CURLOPT_CUSTOMREQUEST => 'POST',

            CURLOPT_POSTFIELDS => array('unique_id' => $unique_code),

        ));



        $response = curl_exec($curl);



        curl_close($curl);



        $response_err = json_decode($response)->errors ?? NULL;



        if ($response_err == 'no_unique_code') {

            ?>

            <div class="error notice">

                <p><?php _e('Błędny klucz, spróbuj ponownie!', 'my_plugin_textdomain'); ?></p>

            </div>

            <?php

        } else {

            $pixel_code = json_decode($response)->data->pixel_code;

            $links = json_decode($response)->data->notification_url;


            $links_for_latest = [];
			$links_for_counter = [];

            if (isset($links)) {

                foreach ($links as $link) {

                    if ($link->type == 'LATEST_CONVERSION') {

                       $links_for_latest[] = $link->notification_key;

                    } elseif ($link->type == 'CONVERSIONS_COUNTER') {

                       $links_for_counter[] = $link->notification_key;

                    }

                }
				
				 update_option('LATEST_CONVERSION',  $links_for_latest, true);
				  update_option('CONVERSIONS_COUNTER',  $links_for_counter, true);
				

            }



            update_option('unique_code', $unique_code, true);

            update_option('pixel_code', $pixel_code, true);



            ?>

            <div class="updated notice">

                <p><?php _e('Poprawnie pobrano dane!', 'my_plugin_textdomain'); ?></p>

            </div>

            <?php
			


        }

    }

}



if (class_exists('NotipackIntegration')) {

    $notipackIntegration = new NotipackIntegration();

    $notipackIntegration->register();

}



register_activation_hook(__FILE__, array($notipackIntegration, 'activate'));

register_deactivation_hook(__FILE__, array($notipackIntegration, 'deactivate'));